/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2011 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WebServicesConsoleModel.as 21083 2011-03-31 08:58:29Z renaultgu $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.webservicesconsole.model {
import com.adobe.cairngorm.model.IModelLocator;

import mx.collections.ArrayCollection;
import mx.utils.UIDUtil;

import org.ow2.jonas.admin.webservicesconsole.business.IWebServicesConsoleDelegate;
import org.ow2.jonas.admin.webservicesconsole.business.WebServicesConsoleDelegate;

/**
 * Model of the Web Service console.
 *
 * @author Guillaume Renault
 */
[Bindable]
public class WebServicesConsoleModel implements IModelLocator {
    //=========================================================================
    //
    //  Static Variables
    //
    //=========================================================================
    /**
     * Model singleton.
     */
    private static var s_WebServicesConsoleModel:WebServicesConsoleModel = null;

    //=========================================================================
    //
    //  Variables
    //
    //=========================================================================
    /**
     * The unique ID of this component.
     *
     * @internal
     *   Used to prevent a Cairngorm issue: when a command event is dispatched,
     * every controller that registered this event type receives it, even if
     * located in another module. To prevent this from happening and triggering
     * multiple severe unexpected concurrence bugs, each event dispatched is
     * postfixed with this unique ID.
     */
    public var componentID:String = UIDUtil.createUID();


    //-------------------------------------------------------------------------
    //  Organism - general informations
    //-------------------------------------------------------------------------

    public var soapRequestSkeleton:String = null;

    public var soapResponse:String = null;

    [ArrayElementType("String")]
    public var operations:ArrayCollection = null;

    //-------------------------------------------------------------------------
    //  Delegate
    //-------------------------------------------------------------------------
    /**
     * Admin service delegate.
     */
    private var m_WebservicesConsoleDelegate:IWebServicesConsoleDelegate = null;

    //=========================================================================
    //
    //  Constructor and Singleton Getter
    //
    //=========================================================================
    /**
     * Constructor. Should not be used, but as AS doesn't allow private constructor, it's
     * up to the developper to take care of this point and to use the getter on the singleton.
     */
    public function WebServicesConsoleModel() {
        super();

        if (WebServicesConsoleModel.s_WebServicesConsoleModel != null) {
            throw new Error("Only one WebServicesConsoleModel can be instantiated.");
        }
    }


    /**
     * Get the unique instance of WebServicesConsoleModel.
     */
    public static function getInstance():WebServicesConsoleModel {
        if (WebServicesConsoleModel.s_WebServicesConsoleModel == null) {
            WebServicesConsoleModel.s_WebServicesConsoleModel = new WebServicesConsoleModel();
        }
        return WebServicesConsoleModel.s_WebServicesConsoleModel;
    }


    //=========================================================================
    //
    //  Methods
    //
    //=========================================================================

    /*#########################################################################
     *
     * Delegate
     *
     ########################################################################*/
    //-------------------------------------------------------------------------
    //  Delegate Getter
    //-------------------------------------------------------------------------

    public function getWebServicesServiceDelegate():IWebServicesConsoleDelegate {
        if (null == this.m_WebservicesConsoleDelegate) {
            this.m_WebservicesConsoleDelegate = new WebServicesConsoleDelegate();
        }
        return this.m_WebservicesConsoleDelegate;
    }

}
}